pub struct SetCollector { /* private fields */ }Trait Implementations
Sourceimpl BaseCollector for SetCollector
impl BaseCollector for SetCollector
Sourcefn insert(&mut self, item: &AnyTuple) -> u64
fn insert(&mut self, item: &AnyTuple) -> u64
Inserts an item into the collector and returns a receipt for undoing the operation.
MODIFIED: Now crate-private as per Step 4 requirements
Sourcefn remove(&mut self, _item: &AnyTuple, receipt: u64)
fn remove(&mut self, _item: &AnyTuple, receipt: u64)
Removes a previously inserted item using its receipt.
The original item is passed back to avoid storing data inside the receipt itself.
MODIFIED: Now crate-private as per Step 4 requirements
Sourcefn result_as_fact(&self) -> Rc<dyn GreynetFact>
fn result_as_fact(&self) -> Rc<dyn GreynetFact>
Returns the aggregated result as a GreynetFact.
Sourceimpl Debug for SetCollector
impl Debug for SetCollector
Sourceimpl Default for SetCollector
impl Default for SetCollector
Sourcefn default() -> SetCollector
fn default() -> SetCollector
Returns the “default value” for a type. Read more